#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <string>       
#include <iostream>     
#include <fstream>     
#include <sstream>
#include <assert.h>  

using namespace std;

/* dalec model */
extern "C" void dalec_deciduous_(int *nday,int *ncycles, double *params,double *driver,double *model) ;

//#define NPAR    19
//#define NCYCLES 50
//#define NEVAL   24000000
#define NDAY    5844
#define YRST    1
#define YREN    14
#define DRIVERFILE "US-Ha1_drivers.csv"
#define CALFILE    "calendar.txt"

int main() {

  double *drivers, *model, *pargsa;
  double  *avgNEEmo, *avgNEEall, *avgGPPmo, *avgGPPall, *avgHRmo, *avgHRall;
  double  *avgLAImo, *avgLAIall, *avgTVCmo, *avgTVCall, *avgTSCmo, *avgTSCall;
  int *caldata, *daymo;
  //int npar    = NPAR    ;
  int nday    = NDAY    ;
  int ncycles = NCYCLES ;
  int yrst    = YRST   ;
  int yren    = YREN   ;

  std::string line    ;
  double dtmp ;

  /* allocate necessary space */
  drivers  = new double[5*nday] ;
  model    = new double[6*nday] ;
  pargsa   = new double[  NPAR] ;
  caldata  = new int[12*16];
  daymo    = new int[12];

  avgNEEmo  = new double[12*NEVAL];
  avgGPPmo  = new double[12*NEVAL];
  avgHRmo   = new double[12*NEVAL];
  avgLAImo  = new double[12*NEVAL];
  avgTVCmo  = new double[12*NEVAL];
  avgTSCmo  = new double[12*NEVAL];
  avgNEEall = new double[NEVAL];
  avgGPPall = new double[NEVAL];
  avgHRall  = new double[NEVAL];
  avgLAIall = new double[NEVAL];
  avgTVCall = new double[NEVAL];
  avgTSCall = new double[NEVAL];


  /* Read drivers */
  FILE *fsetup = fopen(DRIVERFILE,"r") ;
  for ( int j = 0; j < nday; j++ ) {
    for ( int i = 0; i < 5; i++ ) {
      fscanf(fsetup, "%le", &drivers[5*j+i]);
    }
  }
  fclose(fsetup) ;

  /* Read calendar and compute start day for each month */
  ifstream  calfile ;
  calfile.open(CALFILE);
  if ( calfile.fail()) { 
    cout << "Error: could not open " << CALFILE << endl << flush ; 
    return 1; // no point continuing if the file didn't open...
  } 
  int ical = 0;
  std::getline(calfile, line) ; /* skip first line */
  while (std::getline(calfile, line))
  {
    std::stringstream ss(line);
    ss >> dtmp ;
    for (int imo=0; imo<12; imo++)
      ss >> caldata[ical*12+imo] ;
    ical++ ;
  }
  calfile.close() ;

  /* Compute total number of days in each month */
  int dayst = 0;
  for ( int iyr=0; iyr < yrst; iyr++)
    for ( int imo=0; imo < 12; imo++ )
      dayst += caldata[iyr*12+imo]; 
  int totdays = 0;
  for ( int imo=0; imo < 12; imo++ ) {
    daymo[imo] = 0;
    for ( int iyr=yrst; iyr < yren; iyr++)
      daymo[imo] += caldata[iyr*12+imo];
    totdays += daymo[imo];
  }

  /* Read parameters */
  ifstream paramfile ;
  paramfile.open("sgsa.dat");
  if ( paramfile.fail()) { 
    cout << "Error: could not open sgsa.dat" << endl << flush ; 
    return 1; // no point continuing if the file didn't open...
  } 

  int ispl = 0;
  while (std::getline(paramfile, line))
  {

    if ( ispl%10000 ==0 )
      printf("At sample %d\n",ispl);

    /* Read parameters and run model */
    std::stringstream ss(line);
    for ( int i = 0; i < NPAR; i++ ) ss >> pargsa[i] ;
    dalec_deciduous_(&nday,&ncycles,pargsa,drivers,model);

    /* Compute average NEE */
    for ( int imo = 0; imo < 12; imo++ ) avgNEEmo[12*ispl+imo] = 0.0 ;
    int dayadd = dayst;
    for ( int imo = yrst * 12; imo < yren * 12; imo++ ) {
      int yrid = imo / 12;
      int moid = imo - yrid*12;
      for ( int iday=0; iday<caldata[imo]; iday++ )
        avgNEEmo[12*ispl+moid] += model[6*(dayadd+iday)];
      dayadd += caldata[imo];
    }
    avgNEEall[ispl] = 0.0;
    for ( int imo = 0; imo < 12; imo++ ) {
      avgNEEall[ispl] += avgNEEmo[12*ispl+imo];
      avgNEEmo[12*ispl+imo] /= ((double) daymo[imo]);
    }    
    avgNEEall[ispl] /= totdays;

    /* Compute average GPP */
    for ( int imo = 0; imo < 12; imo++ ) avgGPPmo[12*ispl+imo] = 0.0 ;
    dayadd = dayst;
    for ( int imo = yrst * 12; imo < yren * 12; imo++ ) {
      int yrid = imo / 12;
      int moid = imo - yrid*12;
      for ( int iday=0; iday<caldata[imo]; iday++ )
        avgGPPmo[12*ispl+moid] += model[6*(dayadd+iday)+1];
      dayadd += caldata[imo];
    }
    avgGPPall[ispl] = 0.0;
    for ( int imo = 0; imo < 12; imo++ ) {
      avgGPPall[ispl] += avgGPPmo[12*ispl+imo];
      avgGPPmo[12*ispl+imo] /= ((double) daymo[imo]);
    }    
    avgGPPall[ispl] /= totdays;

    /* Compute average HR */
    for ( int imo = 0; imo < 12; imo++ ) avgHRmo[12*ispl+imo] = 0.0 ;
    dayadd = dayst;
    for ( int imo = yrst * 12; imo < yren * 12; imo++ ) {
      int yrid = imo / 12;
      int moid = imo - yrid*12;
      for ( int iday=0; iday<caldata[imo]; iday++ )
        avgHRmo[12*ispl+moid] += model[6*(dayadd+iday)+2];
      dayadd += caldata[imo];
    }
    avgHRall[ispl] = 0.0;
    for ( int imo = 0; imo < 12; imo++ ) {
      avgHRall[ispl] += avgHRmo[12*ispl+imo];
      avgHRmo[12*ispl+imo] /= ((double) daymo[imo]);
    }    
    avgHRall[ispl] /= totdays;

    /* Compute average LAI */
    for ( int imo = 0; imo < 12; imo++ ) avgLAImo[12*ispl+imo] = 0.0 ;
    dayadd = dayst;
    for ( int imo = yrst * 12; imo < yren * 12; imo++ ) {
      int yrid = imo / 12;
      int moid = imo - yrid*12;
      for ( int iday=0; iday<caldata[imo]; iday++ )
        avgLAImo[12*ispl+moid] += model[6*(dayadd+iday)+3];
      dayadd += caldata[imo];
    }
    avgLAIall[ispl] = 0.0;
    for ( int imo = 0; imo < 12; imo++ ) {
      avgLAIall[ispl] += avgLAImo[12*ispl+imo];
      avgLAImo[12*ispl+imo] /= ((double) daymo[imo]);
    }    
    avgLAIall[ispl] /= totdays;

    /* Compute average TVC */
    for ( int imo = 0; imo < 12; imo++ ) avgTVCmo[12*ispl+imo] = 0.0 ;
    dayadd = dayst;
    for ( int imo = yrst * 12; imo < yren * 12; imo++ ) {
      int yrid = imo / 12;
      int moid = imo - yrid*12;
      for ( int iday=0; iday<caldata[imo]; iday++ )
        avgTVCmo[12*ispl+moid] += model[6*(dayadd+iday)+4];
      dayadd += caldata[imo];
    }
    avgTVCall[ispl] = 0.0;
    for ( int imo = 0; imo < 12; imo++ ) {
      avgTVCall[ispl] += avgTVCmo[12*ispl+imo];
      avgTVCmo[12*ispl+imo] /= ((double) daymo[imo]);
    }    
    avgTVCall[ispl] /= totdays;

    /* Compute average TSC */
    for ( int imo = 0; imo < 12; imo++ ) avgTSCmo[12*ispl+imo] = 0.0 ;
    dayadd = dayst;
    for ( int imo = yrst * 12; imo < yren * 12; imo++ ) {
      int yrid = imo / 12;
      int moid = imo - yrid*12;
      for ( int iday=0; iday<caldata[imo]; iday++ )
        avgTSCmo[12*ispl+moid] += model[6*(dayadd+iday)+5];
      dayadd += caldata[imo];
    }
    avgTSCall[ispl] = 0.0;
    for ( int imo = 0; imo < 12; imo++ ) {
      avgTSCall[ispl] += avgTSCmo[12*ispl+imo];
      avgTSCmo[12*ispl+imo] /= ((double) daymo[imo]);
    }    
    avgTSCall[ispl] /= totdays;

    ispl++ ;

  }
  paramfile.close() ;

  FILE *fout = fopen("dalec_spl_NEE.dat","w");
  for ( int i = 0; i < ispl; i++ ){
    fprintf(fout,"%24.16e ",avgNEEall[i]);
    for ( int imo = 0; imo < 12; imo++ ) 
      fprintf(fout,"%24.16e ",avgNEEmo[12*i+imo]);
    fprintf(fout,"\n");
  }
  fclose(fout);

  fout = fopen("dalec_spl_GPP.dat","w");
  for ( int i = 0; i < ispl; i++ ){
    fprintf(fout,"%24.16e ",avgGPPall[i]);
    for ( int imo = 0; imo < 12; imo++ ) 
      fprintf(fout,"%24.16e ",avgGPPmo[12*i+imo]);
    fprintf(fout,"\n");
  }
  fclose(fout);

  fout = fopen("dalec_spl_HR.dat","w");
  for ( int i = 0; i < ispl; i++ ){
    fprintf(fout,"%24.16e ",avgHRall[i]);
    for ( int imo = 0; imo < 12; imo++ ) 
      fprintf(fout,"%24.16e ",avgHRmo[12*i+imo]);
    fprintf(fout,"\n");
  }
  fclose(fout);

  fout = fopen("dalec_spl_LAI.dat","w");
  for ( int i = 0; i < ispl; i++ ){
    fprintf(fout,"%24.16e ",avgLAIall[i]);
    for ( int imo = 0; imo < 12; imo++ ) 
      fprintf(fout,"%24.16e ",avgLAImo[12*i+imo]);
    fprintf(fout,"\n");
  }
  fclose(fout);

  fout = fopen("dalec_spl_TVC.dat","w");
  for ( int i = 0; i < ispl; i++ ){
    fprintf(fout,"%24.16e ",avgTVCall[i]);
    for ( int imo = 0; imo < 12; imo++ ) 
      fprintf(fout,"%24.16e ",avgTVCmo[12*i+imo]);
    fprintf(fout,"\n");
  }
  fclose(fout);

  fout = fopen("dalec_spl_TSC.dat","w");
  for ( int i = 0; i < ispl; i++ ){
    fprintf(fout,"%24.16e ",avgTSCall[i]);
    for ( int imo = 0; imo < 12; imo++ ) 
      fprintf(fout,"%24.16e ",avgTSCmo[12*i+imo]);
    fprintf(fout,"\n");
  }
  fclose(fout);

  delete [] drivers ;
  delete [] model   ;
  delete [] pargsa  ;

  delete [] caldata ;
  delete [] daymo   ;

  delete [] avgNEEmo  ;
  delete [] avgGPPmo  ;
  delete [] avgHRmo   ;
  delete [] avgLAImo  ;
  delete [] avgTVCmo  ;
  delete [] avgTSCmo  ;
  delete [] avgNEEall ;
  delete [] avgGPPall ;
  delete [] avgHRall  ;
  delete [] avgLAIall ;
  delete [] avgTVCall ;
  delete [] avgTSCall ;

  return ( 0 ) ;

}

