#include "stdlib.h"
#include "stdio.h"
#include <math.h>
#include <string>       
#include <iostream>     
#include <fstream>     
#include <sstream>
#include <assert.h>  

using namespace std;

#define NDAY 5844

extern "C" void dalec_deciduous_(int *nday,int *ncycles,
                double *params,double *driver,double *model) ;

int main() {

  double params[24], *drivers, *model;
  int npar    = NPAR    ;
  int nday    = NDAY    ;
  int ncycles = NCYCLES ;

  drivers = new double[5*nday] ;
  model   = new double[6*nday] ;

  /* Read drivers */
  FILE *fsetup = fopen("US-Ha1_drivers.csv","r") ;
  for ( int j = 0; j < nday; j++ ) {
    for ( int i = 0; i < 5; i++ ) {
      fscanf(fsetup, "%le", &drivers[5*j+i]);
      //printf("%d %e\n",i,drivers[5*j+i]);
    }
  }
  fclose(fsetup) ;

  /* Read parameters */
  ifstream paramfile ;
  paramfile.open("params.dat");
  if ( paramfile.fail()) { 
    cout << "Error: could not open params.dat" << endl << flush ; 
    return (1); // no point continuing if the file didn't open...
  } 

  int ispl = 0;
  std::string line ;
  while (std::getline(paramfile, line))
  {

    ispl++ ;

    /* Read parameters and run model */
    std::stringstream ss(line);
    for ( int i = 0; i < npar; i++ ) ss >> params[i] ;

    /* Call DALEC */
    dalec_deciduous_(&nday,&ncycles,params,drivers,model);

    /* Output */
    std::ostringstream sstream;
    sstream << "modelNEE" << ispl << ".dat";
    std::string fname = sstream.str();
    FILE *fout = fopen(fname.c_str(),"w");
    for ( int i = 0; i < nday; i++ ) 
      fprintf(fout,"%d %.12e %.12e\n", i+1,model[6*i],model[6*i+1]) ;
    fclose(fout);

  }
  paramfile.close() ;

  delete [] drivers;
  delete [] model;

  return ( 0 ) ;

}
