#!/bin/bash

# Defaul parameters
runID="./"
iskip=1000000
ithin=10
nkde=200
thinC="OFF"
kde2D="OFF"
kde1D="OFF"
aTOh5="OFF"

# parse command-line arguments
while [[ $# -ge 1 ]]
do
key="$1"
#echo $@
case $key in
    -r|--runID)
    runID=$2
    shift
    ;;
    -s|--skip)
    iskip=$2
    shift
    ;;
    -t|--thin)
    ithin=$2
    shift
    ;;
    -n|--nkde)
    nkde=$2
    shift
    ;;
    --kde2D)
    kde2D=ON
    ;;
    --kde1D)
    kde1D=ON
    ;;
    --thinC)
    thinC=ON
    ;;
    --aTOh5)
    aTOh5=ON
    ;;
    *)
    # unknown option
    echo "Unknown key: ${key}"
    exit
    ;;
esac
shift
done

# Location of kde utility
kdebin="../../../lib/kde/kde"

# Get no. of variables
cd ${runID}
head -1 chain.dat > tmp.dat
nvp3=`awk '{print NF}' tmp.dat`
let "nvp   = $nvp3 - 3"
let "nvpm1 = $nvp  - 1"

# Echo setup
echo "----------------------------------------------------"
echo "Processing run: "${runID}""
echo " - Thinning the chain:        $thinC"
echo " - Compute 1D Marginal pdfs:  $kde1D"
echo " - Compute 2D Marginal pdfs:  $kde2D"
echo " - Convert densities to hdf5: $aTOh5"
echo "Number of variable in the chain: ${nvp}"
echo "Skipping ${iskip}, picking every ${ithin} states"
echo "No of kde points/dimension: ${nkde}"
echo "----------------------------------------------------"

# Thin chain
if [ "$thinC" == "ON" ]
then
  awk -v sk=${iskip} -v th=${ithin} '(NR > sk) && (NR % th == 0) {print $0}' chain.dat > chain.thin
  echo "import numpy as npy"                                        >  tmp.py
  echo "import h5py"                                                >> tmp.py
  echo "din=npy.genfromtxt('chain.thin')"                           >> tmp.py
  echo "h5file = h5py.File('chain.thin.h5','w')"                    >> tmp.py
  echo "h5file.create_dataset('chn', data=din, compression='gzip')" >> tmp.py
  echo "h5file.close()"                                             >> tmp.py
  echo "quit()"                                                     >> tmp.py
  python tmp.py
  /bin/rm tmp.py
fi

if [ "$kde1D" == "ON" ]
then
  # Run marginal kde
  for i in `seq 1 $nvp`
  do
    let "ip1 = $i + 1"
    echo " - Marginal PDF for parameter: $i"
    awk -v ic=${ip1} '{print $ic}' chain.thin > tmp.dat
    ${kdebin} -d 1 -n ${nkde} -f tmp.dat -o dens_${i}.dat
  done
  rm -rf tmp.dat
fi

if [ "$kde2D" == "ON" ]
then
  # Run joint marginal kde
  for i in `seq 1 $nvpm1`
  do
    let "ip1 = $i + 1"
    for j in `seq  $ip1 $nvp`
    do 
      let "jp1 = $j + 1"
      echo " - Joint PDF for parameters: $i $j"
      awk -v ic=${ip1} -v jc=${jp1} '{print $ic"  "$jc}' chain.thin > tmp.dat
      ${kdebin} -d 2 -n ${nkde} -f tmp.dat -o dens_${i}_${j}.dat
    done
  done
  rm -rf tmp.dat
fi

if [ "$aTOh5" == "ON" ]
then
echo "PATH x"                      >  conf1
echo "INPUT-CLASS TEXTFP"          >> conf1
echo "RANK 2"                      >> conf1
echo "DIMENSION-SIZES $nkde $nkde" >> conf1
echo "OUTPUT-CLASS FP"             >> conf1
echo "OUTPUT-SIZE 32"              >> conf1
echo "CHUNKED-DIMENSION-SIZES  $nkde $nkde" >> conf1
echo "COMPRESSION-TYPE GZIP"       >> conf1
echo "COMPRESSION-PARAM 7"         >> conf1
cp conf1 conf2
cp conf1 conf3
sed 's/PATH x/PATH y/'   conf2 > tmp.dat; mv tmp.dat conf2
sed 's/PATH x/PATH p2D/' conf3 > tmp.dat; mv tmp.dat conf3

for i in `seq 1 $nvpm1`
  do
    let "ip1 = $i + 1"
    for j in `seq  $ip1 $nvp`
    do 
      fname=dens_${i}_${j}.dat
      echo " - Converting $fname"
      awk '{print $1}' $fname > tmp1
      awk '{print $2}' $fname > tmp2
      awk '{print $3}' $fname > tmp3
      h5import tmp1 -c conf1 tmp2 -c conf2 tmp3 -c conf3 -o dens_${i}_${j}.h5
      rm -rf $fname
    done
  done
rm conf1 conf2 conf3

echo "PATH x"                         >  conf1
echo "INPUT-CLASS TEXTFP"             >> conf1
echo "RANK 1"                         >> conf1
echo "DIMENSION-SIZES $nkde"          >> conf1
echo "OUTPUT-CLASS FP"                >> conf1
echo "OUTPUT-SIZE 32"                 >> conf1
echo "CHUNKED-DIMENSION-SIZES  $nkde" >> conf1
echo "COMPRESSION-TYPE GZIP"          >> conf1
echo "COMPRESSION-PARAM 7"            >> conf1
cp conf1 conf2
sed 's/PATH x/PATH p1D/' conf2 > tmp.dat; mv tmp.dat conf2
for i in `seq 1 $nvp`
  do
    fname=dens_${i}.dat
    echo " - Converting $fname"
    awk '{print $1}' $fname > tmp1
    awk '{print $2}' $fname > tmp2
    h5import tmp1 -c conf1 tmp2 -c conf2 -o dens_${i}.h5
    rm -rf $fname
  done
rm conf1 conf2

fi

# Return to original location
cd -
