#!/usr/bin/env python

import numpy as npy
import h5py
import matplotlib.pyplot as plt

dlst = [4,6,8,10,12]
run18b   = "dst_d"
run23UPb = "dtrup_d"
run23b   = "dtr_d"

#
#  Correlation length
#
iME = 19; rm18mu = []; rs18mu = []; rm18sg = []; rs18sg = []; rm18cl = []; rs18cl = []
for i in dlst:
    file = h5py.File(run18b+str(i)+"/chain.thin.h5", 'r')   
    chn = npy.array(file["chn"]); file.close()
    rm18mu.append(chn[:,iME].mean())
    rs18mu.append(chn[:,iME].std() )
    rm18sg.append(npy.exp(chn[:,iME+1]).mean())
    rs18sg.append(npy.exp(chn[:,iME+1]).std() )
    rm18cl.append(chn[:,iME+2].mean())
    rs18cl.append(chn[:,iME+2].std() )

iME = 24; rm23UPmu = []; rs23UPmu = []; rm23UPsg = []; rs23UPsg = []; rm23UPcl = []; rs23UPcl = []
for i in dlst:
    file = h5py.File(run23UPb+str(i)+"/chain.thin.h5", 'r')   
    chn = npy.array(file["chn"]); file.close()
    rm23UPmu.append(chn[:,iME].mean())
    rs23UPmu.append(chn[:,iME].std() )
    rm23UPsg.append(npy.exp(chn[:,iME+1]).mean())
    rs23UPsg.append(npy.exp(chn[:,iME+1]).std() )
    rm23UPcl.append(chn[:,iME+2].mean())
    rs23UPcl.append(chn[:,iME+2].std() )

iME = 24; rm23mu = []; rs23mu = []; rm23sg = []; rs23sg = []; rm23cl = []; rs23cl = []
for i in dlst:
    file = h5py.File(run23b+str(i)+"/chain.thin.h5", 'r')   
    chn = npy.array(file["chn"]); file.close()
    rm23mu.append(chn[:,iME].mean())
    rs23mu.append(chn[:,iME].std() )
    rm23sg.append(npy.exp(chn[:,iME+1]).mean())
    rs23sg.append(npy.exp(chn[:,iME+1]).std() )
    rm23cl.append(chn[:,iME+2].mean())
    rs23cl.append(chn[:,iME+2].std() )


dlst = npy.array(dlst)

lw1=3
lw2=2
fs1=18

fig = plt.figure(figsize=(6,4))
ax=fig.add_axes([0.14,0.15,0.8,0.8])
(_,caps1,_)=ax.errorbar(dlst-0.1,rm18cl,  yerr=rs18cl  ,lw=lw1,label=r"$D_{ST}$",  capsize=4)
(_,caps2,_)=ax.errorbar(dlst,    rm23UPcl,yerr=rs23UPcl,lw=lw1,label=r"$D_{TR}^{up}$",capsize=4)
(_,caps3,_)=ax.errorbar(dlst+0.1,rm23cl,  yerr=rs23cl  ,lw=lw1,label=r"$D_{TR}$"  ,capsize=4)

xl=ax.set_xlabel(r"$k_b$",   fontsize=fs1)
yl=ax.set_ylabel(r"$l_c$ [days]",fontsize=fs1)

xt=ax.set_xticks([4,6,8,10,12])
yt=ax.set_yticks([2,3,4,5])

xtks=ax.xaxis.get_major_ticks()+ax.yaxis.get_major_ticks()
for tick in xtks:
    tick.label.set_fontsize(fs1-4)

for cap in caps1+caps2+caps3:
    cap.set_markeredgewidth(lw2)

plt.legend(loc="lower right",prop={'size':fs1})
txt = plt.text(3.2,4.9,"(c)",fontsize=fs1-2,ha='left',va='top')

#plt.show()
plt.savefig("convMEcl.pdf")
plt.close(fig)

fig = plt.figure(figsize=(6,4))
ax=fig.add_axes([0.15,0.15,0.8,0.8])
(_,caps1,_)=ax.errorbar(dlst-0.1,rm18mu,  yerr=rs18mu  ,lw=lw1,label=r"$D_{STS}$")
(_,caps2,_)=ax.errorbar(dlst,    rm23UPmu,yerr=rs23UPmu,lw=lw1,label=r"$D_{UNS}^{up}$")
(_,caps3,_)=ax.errorbar(dlst+0.1,rm23mu,  yerr=rs23mu  ,lw=lw1,label=r"$D_{UNS}$")

xl=ax.set_xlabel(r"$k_b$",   fontsize=fs1)
yl=ax.set_ylabel(r"$\mu\,\,[gC\cdot m^{-2}\cdot day^{-1}]$",fontsize=fs1)

xt=ax.set_xticks([4,6,8,10,12])
yt=ax.set_yticks([-0.6,-0.4,-0.2,0])

xtks=ax.xaxis.get_major_ticks()+ax.yaxis.get_major_ticks()
for tick in xtks:
    tick.label.set_fontsize(fs1-4)

for cap in caps1+caps2+caps3:
    cap.set_markeredgewidth(lw2)

txt = plt.text(3.2,-0.02,"(a)",fontsize=fs1-2,ha='left',va='top')

#plt.show()
plt.savefig("convMEmu.pdf")
plt.close(fig)

fig = plt.figure(figsize=(6,4))
ax=fig.add_axes([0.15,0.15,0.8,0.8])
(_,caps1,_)=ax.errorbar(dlst-0.1,rm18sg,  yerr=rs18sg  ,lw=lw1,label=r"$D_{STS}$")
(_,caps2,_)=ax.errorbar(dlst,    rm23UPsg,yerr=rs23UPsg,lw=lw1,label=r"$D_{UNS}^{up}$")
(_,caps3,_)=ax.errorbar(dlst+0.1,rm23sg,  yerr=rs23sg  ,lw=lw1,label=r"$D_{UNS}$")

xl=ax.set_xlabel(r"$k_b$",   fontsize=fs1)
yl=ax.set_ylabel(r"$\sigma_m\,\,[gC\cdot m^{-2}\cdot day^{-1}]$",fontsize=fs1)

xt=ax.set_xticks([4,6,8,10,12])
yt=ax.set_yticks([0.36,0.4,0.44,0.48])

xtks=ax.xaxis.get_major_ticks()+ax.yaxis.get_major_ticks()
for tick in xtks:
    tick.label.set_fontsize(fs1-4)

for cap in caps1+caps2+caps3:
    cap.set_markeredgewidth(lw2)

txt = plt.text(12,0.475,"(b)",fontsize=fs1-2,ha='left',va='top')

#plt.show()
plt.savefig("convMEsg.pdf")
plt.close(fig)
