#!/usr/bin/env python

import sys, os
import h5py
import numpy as npy
from corr import distcorr

npar=int(sys.argv[1])

vnames=["astem", "br\_mr", "leaffall", "nue", "rg\_frac","tstem","troot",
        "gdd\_min", "gdd\_max", "tsmin", "laimax", "lma", "q10\_mr", "tleaf",
        "br\_lit","br\_som","dr","q10\_hr"]

if npar == 18:
    vnames=["astem", "br\_mr", "br\_lit", "br\_som", "dr", "gdd\_min",
        "gdd\_max", "laimax", "leaffall", 
        "lma", "nue", "q10\_mr", "q10\_hr", "rg\_frac", "tleaf",
        "troot", "tstem", "tsmin"]
    pgrp = [
        ["gdd\_min","gdd\_max","tsmin","laimax","leaffall","lma"], # phenology
        ["nue"],                                                   # photosynthesis
        ["q10\_mr", "br\_mr", "rg\_frac"],                         #
        ["astem"],                                                 #
        ["tstem","troot","tleaf"],                                 #
        ["q10\_hr","br\_lit","br\_som","dr"]                       # literfall
        ]
else:
    vnames = ["astem", "br\_mr", "br\_lit", "br\_som", "dr",
        "gdd\_min", "gdd\_max", "laimax", "leaffall",
        "lma", "nue", "q10\_mr", "q10\_hr", "rg\_frac", "tleaf",
        "troot", "tstem", "tsmin",
        "vc1","vc2","vc3","sc1","sc2"]
    pgrp = [
        ["gdd\_min","gdd\_max","tsmin","laimax","leaffall","lma"], # phenology
        ["nue"],                                                   # photosynthesis
        ["q10\_mr", "br\_mr", "rg\_frac"],                         #
        ["astem"],                                                 #
        ["tstem","troot","tleaf"],                                 #
        ["q10\_hr","br\_lit","br\_som","dr"],                      # literfall
        ["vc1","vc2","vc3"],
        ["sc1","sc2"]
        ]
        

#-Load chain from file
chnfile="chain.thin.h5"
file = h5py.File(chnfile, 'r')   
chn = npy.array(file["chn"])
file.close()

#-Re-shuffle columns as needed
pgrpF = [i for subl in pgrp for i in subl ]
idx   = [vnames.index(i)+1 for i in pgrpF]
chnOrd = chn[:,idx]
print 'Chain size:',chnOrd.shape

#-Compute distance correlations
nskip=0
nthin=100
dc=distcorr(chnOrd[nskip::nthin,:])

print dc
npy.savetxt("dCorr.dat", dc, fmt='%.4e', delimiter='   ', newline='\n')

#######################################################################
dc=npy.genfromtxt("dCorr.dat")
npy.savetxt("dCorr_f.dat", dc, fmt='%.1f', delimiter='   ', newline='\n')
