#!/bin/bash

if [ "$#" -ne 4 ]; then
  echo "usage: ./genSpls.sh nspls iseed fileid npar"
  echo "        nspls:  no. of samples"
  echo "        iseed:  seed for random number generator"
  echo "        fileid: file ID, typically 1 or 2"
  echo "        npar: no of parameters, either 18 or 23"
  exit
fi

nspls=$1
iseed=$2 
fileid=$3
npar=$4

npar=$(( npar + 1 ))

# Parameter types
nrmpar=(1 8 11 12 13 14 15 19 20 21 22 24) # List of normal parameters 
lnrpar=(2 3  4  5 10 16 17 18 23)          # List of log-normal parameters

nrmMu=(0.7   4.0  80.0  7.0 2.0 2.0 0.2   5.0  0.0 9000.0 1500.0 8000.0)
nrmSig=(0.085 0.5  13.0  1.9 0.3 0.3 0.045 1.0 20.0 1800.0  300.0 1600.0)
nrmxmi=(0.1   2.0  20.0  1.0 1.0 1.0 0.05  0.0  0.0    0.0    0.0    0.0)
nrmxma=(0.95  7.0 150.0 20.0 4.0 4.0 0.50 10.0 2.e4   2.e4   2.e4   2.e4)

lnrMu=(-7.87152  -6.46416    -9.21643    -6.51833 -1.93689 -4.21575  -7.32244     -9.62503      2.94686)
lnrSig=( 1.15707  0.359009    0.290978    0.624036 0.604725 0.624036  0.43231      0.43231      0.802669)
lnrxmi=( 1.0e-6   5.479452e-4 2.739726e-5 1.0e-4   0.03     0.001     1.0958904e-4 1.0958904e-5 0.0)
lnrxma=( 1.0e-2   5.479452e-3 2.739726e-4 1.0e-2   0.95     0.100     2.739726e-3  2.739726e-4 1.e3)

# Normal priors
j=0
for i in ${nrmpar[@]}; do
  if [ $i -le $npar ]; then
    echo "Parameter ${i} has a truncated normal prior"
    ./trdSpls -a ${nrmxmi[j]} -b ${nrmxma[j]} -m ${nrmMu[j]} -s ${nrmSig[j]} -n $nspls -i $iseed -t n
    mv samples.dat par${i}.dat
    j=$(( j + 1 ))
    let "iseed += 13"
  fi
done

# Log-Normal priors
j=0
for i in ${lnrpar[@]}; do
  if [ $i -le $npar ]; then
    echo "Parameter ${i} has a truncated log-normal prior"
    ./trdSpls -a ${lnrxmi[j]} -b ${lnrxma[j]} -m ${lnrMu[j]} -s ${lnrSig[j]} -n $nspls -i $iseed -t ln
    mv samples.dat par${i}.dat
    j=$(( j + 1 ))
    let "iseed += 13"
  fi
done

#-par 6,7 (normal,constrains)
let "iseed += 13"
./gddSpls -n $nspls -i $iseed
mv samples.dat par67.dat

#-par 9 leafcn=25
touch par9.dat; /bin/rm par9.dat; touch par9.dat
for i in `seq 1 $nspls`
do
  echo "25.0" >> par9.dat
done

# assemble big matrix
/bin/cp par1.dat sgsa.dat; /bin/rm -rf par1.dat
for i in `seq 2 5` 
do
  paste sgsa.dat par${i}.dat > tmp.dat; /bin/rm -rf par${i}.dat
  /bin/mv tmp.dat sgsa.dat
done
paste sgsa.dat par67.dat > tmp.dat; /bin/rm -rf par67.dat
/bin/mv tmp.dat sgsa.dat
for i in `seq 8 $npar` 
do
  paste sgsa.dat par${i}.dat > tmp.dat; /bin/rm -rf par${i}.dat
  /bin/mv tmp.dat sgsa.dat
done
/bin/mv sgsa.dat sgsa${fileid}.dat

