#!/usr/bin/env python

import os
import sys
import numpy as npy
import matplotlib
import matplotlib.pylab as plt
import matplotlib.cm    as cm
from matplotlib.patches import Circle, Wedge, Polygon
import pylab


vname=sys.argv[1]
TO=int(sys.argv[2])
NEEblock=False
GPPblock=False
TVCblock=False
TSCblock=False
if sys.argv[3]=="vblock":
    if vname=="NEE":
        NEEblock=True;
    elif vname=="GPP":
        GPPblock=True;
    elif vname=="TVC":
        TVCblock=True;
    elif vname=="TSC":
        TSCblock=True;

cdict = cm.jet._segmentdata.copy()
cdict['red']=tuple([tuple([0.0,  1,   1  ]),
                    tuple([0.01, 0,   0  ]),
                    tuple([0.35, 0,   0  ]),
                    tuple([0.66, 1,   1  ]),
                    tuple([0.89, 1,   1  ]),
                    tuple([1,    0.5, 0.5])
                    ]
                   )
cdict['green']=tuple([tuple([0.0,   1, 1]),
                      tuple([0.01,  0, 0]),
                      tuple([0.125, 0, 0]),
                      tuple([0.375, 1, 1]),
                      tuple([0.64,  1, 1]),
                      tuple([0.91,  0, 0]),
                      tuple([1,     0, 0])
                      ]
                     )
cdict['blue']=tuple([tuple([0,    1.0,1.0]), 
                     tuple([0.01, 0.5,0.5]),
                     tuple([0.11, 1,  1  ]),
                     tuple([0.34, 1,  1  ]),
                     tuple([0.65, 0,  0  ]),
                     tuple([1,    0,  0  ])
                     ]
                    )

cp=matplotlib.colors.LinearSegmentedColormap('colormap',cdict,1024)


# 12 months + global average
nvar=13

# Sobol indices
if TO==1:
	sbf="SiT_"+vname+".dat"
	figname = "SiT_"+vname+".pdf"
else:
	sbf="Si_"+vname+".dat"
	figname = "Si_"+vname+".pdf"

# Parameter names
pnames=npy.array(["astem", "br\_mr", "br\_lit", "br\_som", "dr", "gdd", "laimax", "leaffall",
        "lma", "nue", "q10\_mr", "q10\_hr", "rg\_frac", "tleaf", "troot", "tstem", "tsmin"])

# Parameter groups
pgrp=[
    ["gdd","tsmin","laimax","leaffall","lma"], # phenology
    ["nue"],                                   # photosynthesis
    ["q10\_mr", "br\_mr", "rg\_frac"],         #
    ["astem"],                                 #
    ["tstem","troot","tleaf"],                 #
    ["q10\_hr","br\_lit","br\_som","dr"]       # literfall
]
if (NEEblock or GPPblock):
    pgrp=[
        ["gdd","tsmin","laimax","leaffall","lma"], # phenology
        ["nue"],                                   # photosynthesis
        ["q10\_mr", "br\_mr", "rg\_frac"],         #
        ["q10\_hr","br\_lit","br\_som","dr"]       # literfall
    ]
if (TVCblock):
    pgrp=[
        ["gdd","tsmin","laimax","leaffall","lma"], # phenology
        ["nue"],                                   # photosynthesis
        ["q10\_mr", "br\_mr", "rg\_frac"],         #
        ["astem"],                                 #
        ["tstem","troot","tleaf"]                 #
]
if (TSCblock):
    pgrp=[
        ["lma"], # phenology
        ["nue"],                                   # photosynthesis
        ["q10\_mr", "br\_mr", "rg\_frac"],         #
        ["astem"],                                 #
        ["tstem","troot","tleaf"],                 #
        ["q10\_hr","br\_lit","br\_som","dr"]       # literfall
    ]
  

grps = npy.array([1,2,3,4,5,6,7,8,9,10,11,12])
#xtk  = npy.array(["G","J","F","M","A","M","J","J","A","S","O","N","D"])
xtk  = npy.array(["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"])

# flatten groups of parameter names
pgrpf=[item for sublist in pgrp for item in sublist]
# get indices for re-arranging input data
pilst=[npy.where(pnames==i)[0][0] for i in pgrpf]
# get data and re-arrange
sbidx1=npy.genfromtxt(sbf)
sbidx2=npy.zeros((len(pilst),nvar))
for j in range(nvar):
    sbidx2[:,j]=sbidx1[pilst,j]

# Create sensitivity matrix
msens=npy.zeros((len(pilst),len(grps)))
for k in range(len(pilst)):
    msens[k,:] = sbidx2[k,grps.flatten()]

# Block certain months for GPP
if vname=="GPP":
    msens[:,0]=0.0
    msens[:,1]=0.0
    msens[:,11]=0.0

fs1=16;
fs2=22;
#fig = plt.figure(figsize=(11,6));
fig = plt.figure(figsize=(7,6));
ax=fig.add_axes([0.09, 0.23, 0.95, 0.74]);
cs=plt.pcolor(msens.T,cmap=cp);
plt.colorbar();
ax.set_xlim([0,len(pgrpf)]);
ax.set_ylim([0,len(grps)]);
ax.set_xticks([0.5+i for i in range(len(pilst))]);
ax.set_yticks([0.5+i for i in range(len(grps))]);
ax.set_xticklabels(["$"+pgrpf[j].upper()+"$" for j in range(len(pilst))],rotation=90,fontsize=fs1);
#ax.set_yticklabels([xtk[i]+"$"+"("+"%.2f"%(msens[:,i].sum())+")$" for i in range(len(xtk))],fontsize=fs1)
ax.set_yticklabels([xtk[i] for i in range(len(xtk))],fontsize=fs1)

plt.text(-1.5,-2.3,"(a)",fontsize=fs2,ha='left',va='top')
#plt.show();
plt.savefig(figname);
plt.close()

